@@ -19,8 +19,8 @@
 
 import logging,sys,threading,time
 
-from piHAlibs import (confgetval)
-from .corelibs import (lst2lines,startscriptexe,shellexe)
+from piHAlibs import (confgetval,lst2lines)
+from .corelibs import (startscriptexe)
 from .coresetup import (SetupDaemons,
     setupctrl,setupnetctrl,setupsrv,
     startsrv,stopsrv,stopallctrls,
@@ -28,7 +28,7 @@ from .coresetup import (SetupDaemons,
 from .coremctrx import (mctrx)
 from .decoders import (adddecoder,rmdecoder,addparser,rmparser)
 from .rpclcmds import (RPCLocalFunctions)
-from .usercmds import (UserCmds)
+
 
 logger = logging.getLogger()
 
@@ -65,6 +65,4 @@ AdminCmds = {
     'STOPall':stopallctrls,
     'STOPsrv':stopsrv,
     'RUN':runscript,
-    'SHELL' : shellexe,
     }
-AdminCmds.update(UserCmds)
