@@ -22,20 +22,20 @@ logger = logging.getLogger()
 
 ATIRParsers = {
     ('0x14', '0x14'): ('ati', 'rxremote'),
-    ('0x20', '0x20'): ('x10', 'devdecoder rxremote'),
+    ('0x20', '0x20'): ('x10', 'devdecoder detdecoder rxremote'),
     }
 
 CM15Parsers = {
     ('0x5d','0x14'):('ati','rxremote'),
     ('0x5d','0x20'):('x10','devdecoder detdecoder rxremote'),
-    ('0x5d','0x29'):('x10s','detdecoder rxremote'),
+    ('0x5d','0x29'):('x10s','devdecoder detdecoder rxremote'),
     }
 
 RFXCOMParsers = {
     ('0x14','0x14'):('ati','rxremote'),
-    ('0x20','0x20'):('x10','detdecoder devdecoder rxremote'),
-    ('0x29','0x29'):('x10s','detdecoder rxremote'),
-    ('0x22','NC'):('arctech','detremote devdecoder rxremote'),
+    ('0x20','0x20'):('x10','devdecoder detdecoder rxremote'),
+    ('0x29','0x29'):('x10s','devdecoder detdecoder rxremote'),
+    ('0x22','0x22'):('arctech','devdecoder detdecoder rxremote'),
     ('0x50','0x1a2d'):('oregon','oredecoder'),
     ('0x50','0xfa28'):('oregon','oredecoder'),
     ('0x5c','0x2a19'):('oregon','oredecoder'),
@@ -76,14 +76,15 @@ RFXCOMParsers = {
     }
 
 TSDUOParsers = {
-    ('arctech','selflearning'):('devdecoder','0x22'),
-    ('x10','NC'):('devdecoder','0x20'),
+    ('arctech','selflearning'):('devdecoder detdecoder rxremote','0x22'),
+    ('x10','NC'):('devdecoder detdecoder rxremote','0x20'),
     ('oregon','0xea4c'):('oredecoder','0x44'),
-    ('everflourish','NC'):('devdecoder','0x22'),
+    ('everflourish','NC'):('devdecoder detdecoder rxremote','0x22'),
     }
 
 DETDECODERS = {
     ('0x20','x10') : ('chkx10rf(p)', '', 'cvh2x10rf(p)') ,
+    ('0x22','arctech') : ('','','archuf(p)') ,
     ('0x29','x10s') : ('chkssec1(p)', 'chkssec2(p)', 'evalhuf1(data)') ,
     }
 
@@ -94,8 +95,10 @@ DEVDECODERS = {
 
 REMDECODERS = {
     ('0x14','ati') : ('','','atirmap(p)') ,
-    ('0x20','x10') : ('chksrfr(p)','','pcrmap(p)') ,
+    ('0x20','x10r') : ('chksrfr(p)','','pcrmap(p)') ,
+    ('0x20','x10') : ('chkx10rf(p)','','cvh2x10rf(p)') ,
     ('0x22','arctech') : ('','','archuf(p)') ,
+    ('0x29','x10s') : ('chkssec1(p)', 'chkssec2(p)', 'evalhuf1(data)') ,
     }
 
 OREDECODERS = {
